@@ -1,19 +1,40 @@
 import numpy as np
 
 from StructuralCausalModels.graph import Graph
-from StructuralCausalModels.graph import InvalidAdjacencyMatrix
+from StructuralCausalModels.graph_via_adjacency_matrix import \
+    InvalidAdjacencyMatrix
 
 
 class DirectedGraph(Graph):
+    """A class to represent directed graphs.
 
-    def __init__(self, name, adjacency_matrix):
+    A DirectedGraph object is a representation of a directed graph. It is
+    defined by the adjacency matrix of the graph ; validation will be performed
+    to check that the graph defined is directed. An exception will be raised
+    otherwise.
+
+    Parameters
+    ----------
+    adjacency_matrix : array_like
+        The adjacency matrix of the graph.
+    name : str, optional
+        The name of the object created (default is '').
+
+    Raises
+    ------
+    InvalidAdjacencyMatrix
+        If the adjacency matrix does not define a directed graph.
+    """
+
+    def __init__(self, adjacency_matrix, name=''):
 
         if not DirectedGraph.validate_directed_graph_adjacency_matrix(
                 adjacency_matrix):
             msg = 'Adjacency matrix provided not valid for a directed graph.'
             raise InvalidAdjacencyMatrix(msg)
 
-        super().__init__(name, adjacency_matrix)
+        super().__init__(name=name,
+                         adjacency_matrix=adjacency_matrix)
 
     @staticmethod
     def validate_directed_graph_adjacency_matrix(matrix):
@@ -28,8 +49,8 @@ class DirectedGraph(Graph):
         Returns
         -------
         bool
-            Whether the matrix to check is a valid adjacency matrix for a directed
-            graph.
+            Whether the matrix to check is a valid adjacency matrix for a
+            directed graph.
         """
         if not Graph.validate_binary_matrix(matrix):
             return False
